<no title> — cis_interface 0.3.0 documentation

Model YAML:

     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    19
    20
    21
    22
    23
    24
    25
    26
    27
    28
    models:
      - name: python_modelA
        language: python
        args: ./src/gs_lesson4b_modelA.py

        inputs:
          - name: inputA
            driver: FileInputDriver
            args: ./Input/input.txt

        outputs:
          - name: outputA
            driver: OutputDriver  # Output to another channel
            args: A_to_B  # Connection to inputB

      - name: python_modelB
        language: python
        args: ./src/gs_lesson4b_modelB.py

        inputs:
          - name: inputB
            driver: InputDriver  # Input from another channel
            args: A_to_B  # Conneciton to inputA

        outputs:
          - name: outputB
            driver: FileOutputDriver
            args: ./output.txt

(Example in other languages)